"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from honeyhive.types import BaseModel
from typing import Optional, TypedDict
from typing_extensions import NotRequired


class CreateProjectRequestTypedDict(TypedDict):
    name: str
    description: NotRequired[str]


class CreateProjectRequest(BaseModel):
    name: str

    description: Optional[str] = None
