"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .evaluationrun import EvaluationRun, EvaluationRunTypedDict
from honeyhive.types import BaseModel
from typing import List, Optional, TypedDict
from typing_extensions import NotRequired


class GetRunsResponseTypedDict(TypedDict):
    evaluations: NotRequired[List[EvaluationRunTypedDict]]


class GetRunsResponse(BaseModel):
    evaluations: Optional[List[EvaluationRun]] = None
