"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from honeyhive.types import BaseModel
from honeyhive.utils import FieldMetadata, QueryParamMetadata
import httpx
from typing import TypedDict
from typing_extensions import Annotated


class DeleteDatasetRequestTypedDict(TypedDict):
    dataset_id: str
    r"""The unique identifier of the dataset to be deleted like `663876ec4611c47f4970f0c3`"""


class DeleteDatasetRequest(BaseModel):
    dataset_id: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]
    r"""The unique identifier of the dataset to be deleted like `663876ec4611c47f4970f0c3`"""


class DeleteDatasetResponseTypedDict(TypedDict):
    content_type: str
    r"""HTTP response content type for this operation"""
    status_code: int
    r"""HTTP response status code for this operation"""
    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""


class DeleteDatasetResponse(BaseModel):
    content_type: str
    r"""HTTP response content type for this operation"""

    status_code: int
    r"""HTTP response status code for this operation"""

    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""
