"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from honeyhive import utils
from honeyhive.types import BaseModel
import httpx
import pydantic
from typing import List, Optional
from typing_extensions import Annotated


class CreateEventBatchResponseBodyData(BaseModel):
    event_ids: Optional[List[str]] = None

    errors: Optional[List[str]] = None

    success: Optional[bool] = None

    raw_response: Annotated[Optional[httpx.Response], pydantic.Field(exclude=True)] = (
        None
    )
    r"""Raw HTTP response; suitable for custom response parsing"""


class CreateEventBatchResponseBody(Exception):
    r"""Events partially created"""

    data: CreateEventBatchResponseBodyData

    def __init__(self, data: CreateEventBatchResponseBodyData):
        self.data = data

    def __str__(self) -> str:
        return utils.marshal_json(self.data, CreateEventBatchResponseBodyData)
