"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from honeyhive.models.components import datapoint as components_datapoint
from honeyhive.types import BaseModel
from honeyhive.utils import FieldMetadata, QueryParamMetadata
import httpx
from typing import List, Optional, TypedDict
from typing_extensions import Annotated, NotRequired


class GetDatapointsRequestTypedDict(TypedDict):
    project: str
    r"""Project name to filter datapoints"""
    datapoint_ids: NotRequired[List[str]]
    r"""List of datapoint ids to fetch"""
    dataset_name: NotRequired[str]
    r"""Name of the dataset to get datapoints from"""


class GetDatapointsRequest(BaseModel):
    project: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]
    r"""Project name to filter datapoints"""

    datapoint_ids: Annotated[
        Optional[List[str]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""List of datapoint ids to fetch"""

    dataset_name: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""Name of the dataset to get datapoints from"""


class GetDatapointsResponseBodyTypedDict(TypedDict):
    r"""Successful response"""

    datapoints: NotRequired[List[components_datapoint.DatapointTypedDict]]


class GetDatapointsResponseBody(BaseModel):
    r"""Successful response"""

    datapoints: Optional[List[components_datapoint.Datapoint]] = None


class GetDatapointsResponseTypedDict(TypedDict):
    content_type: str
    r"""HTTP response content type for this operation"""
    status_code: int
    r"""HTTP response status code for this operation"""
    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""
    object: NotRequired[GetDatapointsResponseBodyTypedDict]
    r"""Successful response"""


class GetDatapointsResponse(BaseModel):
    content_type: str
    r"""HTTP response content type for this operation"""

    status_code: int
    r"""HTTP response status code for this operation"""

    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""

    object: Optional[GetDatapointsResponseBody] = None
    r"""Successful response"""
