"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .evaluationrun import EvaluationRun, EvaluationRunTypedDict
from honeyhive.types import BaseModel
from typing import Optional, TypedDict
from typing_extensions import NotRequired


class GetRunResponseTypedDict(TypedDict):
    evaluation: NotRequired[EvaluationRunTypedDict]


class GetRunResponse(BaseModel):
    evaluation: Optional[EvaluationRun] = None
