"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from honeyhive.models.components import tool as components_tool
from honeyhive.types import BaseModel
import httpx
from typing import List, Optional, TypedDict
from typing_extensions import NotRequired


class GetToolsResponseTypedDict(TypedDict):
    content_type: str
    r"""HTTP response content type for this operation"""
    status_code: int
    r"""HTTP response status code for this operation"""
    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""
    tools: NotRequired[List[components_tool.ToolTypedDict]]
    r"""Successfully retrieved the list of tools"""


class GetToolsResponse(BaseModel):
    content_type: str
    r"""HTTP response content type for this operation"""

    status_code: int
    r"""HTTP response status code for this operation"""

    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""

    tools: Optional[List[components_tool.Tool]] = None
    r"""Successfully retrieved the list of tools"""
