"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from honeyhive.types import BaseModel
from typing import Any, Dict, Optional, TypedDict
from typing_extensions import NotRequired


class UpdateToolRequestTypedDict(TypedDict):
    id: str
    name: str
    parameters: Dict[str, Any]
    description: NotRequired[str]


class UpdateToolRequest(BaseModel):
    id: str

    name: str

    parameters: Dict[str, Any]

    description: Optional[str] = None
