"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from honeyhive.models.components import createmodelevent as components_createmodelevent
from honeyhive.types import BaseModel
import httpx
from typing import Optional, TypedDict
from typing_extensions import NotRequired


class CreateModelEventRequestBodyTypedDict(TypedDict):
    model_event: NotRequired[components_createmodelevent.CreateModelEventTypedDict]


class CreateModelEventRequestBody(BaseModel):
    model_event: Optional[components_createmodelevent.CreateModelEvent] = None


class CreateModelEventResponseBodyTypedDict(TypedDict):
    r"""Model event created"""

    event_id: NotRequired[str]
    success: NotRequired[bool]


class CreateModelEventResponseBody(BaseModel):
    r"""Model event created"""

    event_id: Optional[str] = None

    success: Optional[bool] = None


class CreateModelEventResponseTypedDict(TypedDict):
    content_type: str
    r"""HTTP response content type for this operation"""
    status_code: int
    r"""HTTP response status code for this operation"""
    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""
    object: NotRequired[CreateModelEventResponseBodyTypedDict]
    r"""Model event created"""


class CreateModelEventResponse(BaseModel):
    content_type: str
    r"""HTTP response content type for this operation"""

    status_code: int
    r"""HTTP response status code for this operation"""

    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""

    object: Optional[CreateModelEventResponseBody] = None
    r"""Model event created"""
