"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from honeyhive.types import BaseModel
from typing import Optional, TypedDict
from typing_extensions import NotRequired


class DeleteRunResponseTypedDict(TypedDict):
    id: NotRequired[str]
    deleted: NotRequired[bool]


class DeleteRunResponse(BaseModel):
    id: Optional[str] = None

    deleted: Optional[bool] = None
